#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2021-07-15
#
# Check_MK cisco_wlc_power WATO plugin
#
# 2021-07-15: initial version
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    MonitoringState,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_cisco_wlc_power():
    return Dictionary(elements=[
        ('not_present',
         MonitoringState(
             default_value=2,
             title=_('State if the power supply is not present.'),
             help=_('The monitoring state is the power supply is not present')
         )),
        ('not_operational',
         MonitoringState(
             default_value=2,
             title=_('State if the power supply is not operational.'),
             help=_('The monitoring state is the power supply is not operational')
         )),

    ])


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_wlc_power',
        group=RulespecGroupCheckParametersNetworking,
        item_spec=lambda: TextAscii(title=_('Power Supply #'), ),
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_wlc_power,
        title=lambda: _('Cisco WLC power supply'),
    ))
